==> wiki3_5_3.zip: wiki3_5_3/plugin/rename/RenameForm.pm <==
############################################################
#
# ڡ̾Τѹ뤿ΥեϤޤ
#
############################################################
package plugin::rename::RenameForm;
use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# إפɽޤ
#===========================================================
sub editform {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI();
	my $page = $cgi->param("page");
	
	# ڡ¸ߤեɽ
	if($wiki->page_exists($page)){
		my $time = $wiki->get_last_modified($page);
		return "<h2>͡ࡦԡ</h2>".
		       "<form method=\"post\" action=\"".$wiki->config('script_name')."\">\n".
		       "  <input type=\"text\" name=\"newpage\" size=\"40\">\n".
		       "  <br>\n".
		       "  <input type=\"radio\"  name=\"do\" value=\"move\" checked>͡\n".
		       "  <input type=\"radio\"  name=\"do\" value=\"movewm\">åĤƥ͡\n".
		       "  <input type=\"radio\"  name=\"do\" value=\"copy\">ԡ\n".
		       "  <input type=\"submit\" name=\"execute_rename\" value=\" ¹ \">\n".
		       "  <input type=\"hidden\" name=\"action\" value=\"RENAME\">".
		       "  <input type=\"hidden\" name=\"lastmodified\" value=\"".&Util::escapeHTML($time)."\">\n".
		       "  <input type=\"hidden\" name=\"page\" value=\"".&Util::escapeHTML($cgi->param('page'))."\">".
		       "</form>\n";
	}
}

1;

==> wiki3_6_2.zip: wiki3_6_2/plugin/rename/RenameForm.pm <==
############################################################
#
# ڡ̾Τѹ뤿ΥեϤޤ
#
############################################################
package plugin::rename::RenameForm;
use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# إפɽޤ
#===========================================================
sub editform {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI();
	my $page = $cgi->param("page");
	
	# ڡ¸ߤեɽ
	if($wiki->page_exists($page)){
		my $time = $wiki->get_last_modified($page);
		return "<h2>͡ࡦԡ</h2>".
		       "<form method=\"post\" action=\"".$wiki->config('script_name')."\">\n".
		       "  <input type=\"text\" name=\"newpage\" size=\"40\" value=\"".&Util::escapeHTML($page)."\">\n".
		       "  <br>\n".
		       "  <input type=\"radio\"  name=\"do\" value=\"move\" checked>͡\n".
		       "  <input type=\"radio\"  name=\"do\" value=\"movewm\">åĤƥ͡\n".
		       "  <input type=\"radio\"  name=\"do\" value=\"copy\">ԡ\n".
		       "  <input type=\"submit\" name=\"execute_rename\" value=\" ¹ \">\n".
		       "  <input type=\"hidden\" name=\"action\" value=\"RENAME\">".
		       "  <input type=\"hidden\" name=\"lastmodified\" value=\"".&Util::escapeHTML($time)."\">\n".
		       "  <input type=\"hidden\" name=\"page\" value=\"".&Util::escapeHTML($page)."\">".
		       "</form>\n";
	}
}

1;
